@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthBasic.php,v 1.4 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthBasic.php,v 1.5 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthBasic.php,v 1.4 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthBasic.php,v 1.5 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AuthBasic extends SyL_Auth
@@ -67,7 +67,10 @@ class SyL_AuthBasic extends SyL_Auth
 
         // ѥ᡼Ƚ
         if (isset($_SERVER['PHP_AUTH_USER']) && ($_SERVER['PHP_AUTH_USER'] !== '')) {
+            SyL_Loggers::info("[Auth] Login Action: true");
             return true;
+        } else {
+            SyL_Loggers::info("[Auth] Login Action: false");
         }
 
         // ١åǧɽ
@@ -103,14 +106,15 @@ HTML;
         // REQUEST_METHODŪѹ
         $request_method = $_SERVER['REQUEST_METHOD'];
 
+        list($id, $passwd) = $this->getLoginParameterName();
         $_SERVER['REQUEST_METHOD'] = 'POST';
-        $_POST[$this->username] = isset($_SERVER['PHP_AUTH_USER']) ? $_SERVER['PHP_AUTH_USER'] : '';
-        $_POST[$this->password] = isset($_SERVER['PHP_AUTH_PW'])   ? $_SERVER['PHP_AUTH_PW']   : '';
+        $_POST[$id]     = isset($_SERVER['PHP_AUTH_USER']) ? $_SERVER['PHP_AUTH_USER'] : '';
+        $_POST[$passwd] = isset($_SERVER['PHP_AUTH_PW'])   ? $_SERVER['PHP_AUTH_PW']   : '';
 
         list(,$type) = explode(':', SYL_AUTH_TYPE, 2);
         $auth =& SyL_Auth::singleton($type);
-        $auth->setUserParamaterName($this->username);
-        $auth->setPasswordParamaterName($this->password);
+        $auth->setUserParamaterName($id);
+        $auth->setPasswordParamaterName($passwd);
         $result = $auth->doLogin();
 
         $_SERVER['REQUEST_METHOD'] = $request_method;
