@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.16 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.17 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.16 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.17 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigComponents extends SyL_Config
@@ -47,18 +47,29 @@ class SyL_ConfigComponents extends SyL_Config
     /**
      * ٥̾
      * 
-     * @access private
+     * @access protected
      * @var string
      */
     var $event = 'initStream';
     /**
      * ǥեȼ¹Խ
      * 
-     * @access private
+     * @access protected
      * @param int
      */
     var $default_priority = 3;
 
+    /**
+     * ƥȤ򥻥å
+     * ƥȤʤΤǡåȤʤ褦˥С饤
+     *
+     * @access protected
+     * @param object ȥ饪֥
+     */
+    function setContext(&$controller)
+    {
+    }
+
     /**
      * XMLեβϽ
      *
@@ -68,7 +79,7 @@ class SyL_ConfigComponents extends SyL_Config
     {
         if (SYL_CACHE) {
             // åѤ
-            $key = implode('', $this->file_names);
+            $key = SYL_PROJECT_DIR;
             $cache =& $this->getCache($key);
             if ($cache) {
                 // å夬Ǥʤäʥå奪֥Ȥ
