@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.1 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.2 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.1 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.2 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Action
@@ -66,10 +66,15 @@ class SyL_Action
     {
     }
 
+
+    // -----------------------------------------------------
+    // DBϢ̥᥽å
+    // -----------------------------------------------------
+
     /**
      * DB֥Ȥ
      *
-     * @access public
+     * @access protected
      * @param string DSNʸ
      * @return object DB֥
      */
@@ -77,12 +82,14 @@ class SyL_Action
     {
         static $dsns = array();
         if (!isset($dsns[$dsn])) {
+            // DB饹󥯥롼
             include_once SYL_INCLUDE_DIR . '/lib/SyL_DB.php';
+            // DB֥ȼ
             $dsns[$dsn] =& SyL_DB::getConnection($dsn);
             $dsns[$dsn]->setCallbackSqlLog(array(__CLASS__, 'addLogDBSql'));
             $dsns[$dsn]->setCallbackErrorLog(array(__CLASS__, 'addLogDBError'));
             //register_shutdown_function(array(&$dsns[$dsn], 'closeConnection'));
-            SyL_Loggers::info("[Action] DB start connection");
+            SyL_Loggers::info("[Action] DB connection start");
         }
         return $dsns[$dsn];
     }
@@ -90,7 +97,7 @@ class SyL_Action
     /**
      * DB֥Ȥ³
      *
-     * @access public
+     * @access protected
      * @param object DB֥
      */
     function closeDB(&$conn)
@@ -98,7 +105,7 @@ class SyL_Action
         if (is_object($conn)) {
             $conn->closeConnection();
             $conn = null;
-            SyL_Loggers::info("[Action] DB end connection");
+            SyL_Loggers::info("[Action] DB connection end");
         }
     }
 
@@ -127,9 +134,70 @@ class SyL_Action
     }
 
 
+    // -----------------------------------------------------
+    // ǧڴϢ̥᥽å
+    // -----------------------------------------------------
+
+    /**
+     * 桼֥Ȥ
+     *
+     * @access protected
+     * @return object 桼֥
+     */
+    function getUser()
+    {
+        // ǧڥ֥ȼ
+        if (!class_exists('SyL_Auth')) {
+            trigger_error("[SyL error] SyL_Auth object not declared. use `SyL_FilterAuth' filter ?", E_USER_ERROR);
+        }
+        $auth =& SyL_Auth::singleton();
+        return $auth->getUser();
+    }
+
+    /**
+     * Ȥ
+     *
+     * @access protected
+     * @return object 桼֥
+     */
+    function doLogout()
+    {
+        // ǧڥ֥ȼ
+        if (!class_exists('SyL_Auth')) {
+            trigger_error("[SyL error] SyL_Auth object not declared. use `SyL_FilterAuth' filter ?", E_USER_ERROR);
+        }
+        $auth =& SyL_Auth::singleton();
+        $auth->doLogout();
+    }
+
+
+    // -----------------------------------------------------
+    // եϢ̥᥽å
+    // -----------------------------------------------------
+
+    /**
+     * ե४֥Ȥ
+     *
+     * @access protected
+     * @param object ǡ֥
+     * @param string ե९饹̾
+     * @return object ե४֥
+     */
+    function &getActionForm(&$data, $form_class)
+    {
+        // ե।󥯥롼
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_ActionForm.php';
+        // ե
+        $form =& SyL_ActionForm::factory($form_class);
+        // ǡ֥ȥå
+        $form->registerInput($data);
+        // ե๽
+        $form->build();
+
+        return $form;
+    }
+
     // validate
-    // auth
-    // form
 }
 
 ?>
