@@ -27,11 +27,16 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.6 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.7 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+/**
+ * 桼饹
+ */
+require_once SYL_INCLUDE_DIR . '/framework/SyL_User.php';
+
 /**
  * ǧڥ饹
  *
@@ -39,7 +44,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.6 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.7 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Auth
@@ -57,30 +62,7 @@ class SyL_Auth
      * @access private
      * @var string
      */
-    var $session_name = 'syl_auth_session';
-    /**
-     * 桼IDѥ᡼̾
-     * 
-     * @access private
-     * @var string
-     */
-    var $username = 'login_username';
-    /**
-     * ѥɥѥ᡼̾
-     * 
-     * @access private
-     * @var string
-     */
-    var $password = 'login_passwd';
-    /**
-     * ѥǧڤŹ沽ϥå岽ƹԤ
-     *
-     * ξϡʿʸ
-     * 
-     * @access private
-     * @var string
-     */
-    var $password_func = 'md5';
+    var $session_name = '';
     /**
      * ͤ򥻥åȤ륻åѿ̾
      *
@@ -96,10 +78,6 @@ class SyL_Auth
      */
     function SyL_Auth()
     {
-        list($username, $password) = explode(':', SYL_AUTH_LOGIN_PARAMETER, 2);
-        // ǧڥѥ᡼̾å
-        $this->setUserParamaterName($username);
-        $this->setPasswordParamaterName($password);
     }
 
     /**
@@ -117,13 +95,24 @@ class SyL_Auth
         }
 
         if (!isset($singleton[$type])) {
-            SyL_Loggers::info("[Auth] Type {$type}");
+            SyL_Loggers::info("[Auth] Create Auth Type: {$type}");
 
             $classname = 'SyL_Auth' . ucfirst($type);
             include_once SYL_INCLUDE_DIR . "/framework/Auth/{$classname}.php";
-            $request =& SyL_Request::singleton();
+            // ǧڥ֥Ⱥ
             $singleton[$type] = new $classname();
+            // 桼饹
+            $classname = SYL_AUTH_USER_CLASS ? SyL_Loader::convertClass(SYL_AUTH_USER_CLASS, true) : 'SyL_User';
+            // å󥪥֥ȥå
+            $request =& SyL_Request::singleton();
             $singleton[$type]->setSessionObject($request->getSessionObject());
+            // å̾å
+            $singleton[$type]->setSessionName($classname);
+            $user = $singleton[$type]->getUser();
+            // 桼֥ȤƤʤޤϥ󤷤Ƥʤк
+            if (!$user) {
+                $singleton[$type]->setUser(new $classname());
+            }
         }
         return $singleton[$type];
     }
@@ -139,32 +128,10 @@ class SyL_Auth
         $this->session =& $session;
     }
 
-    /**
-     * 桼IDѥ᡼̾򥻥å
-     * 
-     * @access public
-     * @param string 桼IDѥ᡼̾
-     */
-    function setUserParamaterName($username)
-    {
-        $this->username = $username;
-    }
-
-    /**
-     * ѥɥѥ᡼̾򥻥å
-     * 
-     * @access public
-     * @param string ѥɥѥ᡼̾
-     */
-    function setPasswordParamaterName($password)
-    {
-        $this->password = $password;
-    }
-
     /**
      * å̾򥻥å
      * 
-     * @access public
+     * @access private
      * @param string å̾
      */
     function setSessionName($session_name)
@@ -173,14 +140,37 @@ class SyL_Auth
     }
 
     /**
-     * ѥɰŹ沽ؿ̾򥻥å
+     * 桼֥ȼ
      * 
      * @access public
-     * @param string ѥɰŹ沽ؿ̾
+     * @return object 桼֥
      */
-    function setPasswordFunc($password_func)
+    function getUser()
     {
-        $this->password_func = $password_func;
+        return $this->session->get($this->session_name);
+    }
+
+    /**
+     * 桼֥Ȥ򥻥å
+     * 
+     * @access public
+     * @param object 桼֥
+     */
+    function setUser($user)
+    {
+        return $this->session->set($this->session_name, $user);
+    }
+
+    /**
+     * ѥ᡼̾
+     * 
+     * @access public
+     * @return array ѥ᡼
+     */
+    function getLoginParameterName()
+    {
+        $user = $this->getUser();
+        return array($user->getUserIdParamaterName(), $user->getPasswordParamaterName());
     }
 
     /**
@@ -209,7 +199,15 @@ class SyL_Auth
      */
     function isLoginAction()
     {
-        return (($_SERVER['REQUEST_METHOD'] == 'POST') && isset($_POST[$this->username]) && isset($_POST[$this->password]));
+        list($id, $passwd) = $this->getLoginParameterName();
+            SyL_Loggers::info("[Auth] a: $id, $passwd");
+        if (($_SERVER['REQUEST_METHOD'] == 'POST') && isset($_POST[$id]) && isset($_POST[$passwd])) {
+            SyL_Loggers::info("[Auth] Login Action: true");
+            return true;
+        } else {
+            SyL_Loggers::info("[Auth] Login Action: false");
+            return false;
+        }
     }
 
     /**
@@ -298,12 +296,21 @@ class SyL_Auth
             SyL_Loggers::info("[Auth] Auth hash CL: (none) SV: (none) challenge: off");
         }
 
+        // 桼֥ȼ
+        $user = $this->getUser();
         if ($server_password === $client_password) {
-            $this->session->set($this->session_name, $client_username);
             SyL_Loggers::info("[Auth] Login Success. (class: " . get_class($this) . " user: {$client_username})");
+            // 桼IDå
+            $user->setUserId($client_username);
+            // OK٥
+            $user->triggerLoginSuccess();
+            $this->setUser($user);
             return true;
         } else {
             SyL_Loggers::warn("[Auth] Login Failed. Invalid Password. (class: " . get_class($this) . " user: {$client_username})");
+            // 󥨥顼٥
+            $user->triggerLoginFailed();
+            $this->setUser($user);
             return false;
         }
     }
@@ -316,18 +323,18 @@ class SyL_Auth
      */
     function isLogin()
     {
-        return $this->session->is($this->session_name);
+        $user = $this->getUser();
+        return $user->isLogin();
     }
 
     /**
-     * ǧڥå
+     * ǧں
      * 
      * @access public
-     * @return bool OK: ǧOK, NG: ǧNG
      */
     function deleteLogin()
     {
-        $this->session->delete($this->session_name);
+        $this->setUser(null);
     }
 
     /**
@@ -338,9 +345,13 @@ class SyL_Auth
      */
     function doLogout()
     {
-        $client_username = $this->session->get($this->session_name);
+        $user = $this->getUser();
+        $client_username = $user->getUserId();
         SyL_Loggers::info("[Auth] Logout Success. (class: " . get_class($this) . " user: {$client_username})");
+        // ȥ٥
+        $user->triggerLogout();
         $this->deleteLogin();
+        session_destroy();
     }
 
     /**
@@ -417,6 +428,32 @@ class SyL_Auth
         SyL_Response::redirect(call_user_func(array(__CLASS__, 'getAuthUrl')) . $query_string);
     }
 
+    /**
+     * 󥨥顼URL
+     * 
+     * @static
+     * @access public
+     */
+    function getAuthLoginErrorUrl()
+    {
+        if (SYL_AUTH_LOGIN_ERROR_URL) {
+            return SYL_AUTH_LOGIN_ERROR_URL;
+        } else {
+            trigger_error("[SyL error] Define `SYL_AUTH_LOGIN_ERROR_URL' not value");
+        }
+    }
+
+    /**
+     * 󥨥顼̤إ쥯
+     * 
+     * @static
+     * @access public
+     */
+    function redirectLoginError()
+    {
+        SyL_Response::redirect(call_user_func(array(__CLASS__, 'getAuthLoginErrorUrl')));
+    }
+
     /**
      * å󥨥顼URL
      * 
@@ -425,7 +462,11 @@ class SyL_Auth
      */
     function getAuthSessionErrorUrl()
     {
-        return SYL_AUTH_SESSION_ERROR_URL ? SYL_AUTH_SESSION_ERROR_URL : '/';
+        if (SYL_AUTH_SESSION_ERROR_URL) {
+            return SYL_AUTH_SESSION_ERROR_URL;
+        } else {
+            trigger_error("[SyL error] Define `SYL_AUTH_SESSION_ERROR_URL' not value");
+        }
     }
 
     /**
@@ -433,16 +474,11 @@ class SyL_Auth
      * 
      * @static
      * @access public
-     * @param string ɲåꥹȥ
      */
-    function redirectSessionError($query_string='')
+    function redirectSessionError()
     {
-        if ($query_string) {
-            $query_string = '?' . $query_string;
-        }
-        SyL_Response::redirect(call_user_func(array(__CLASS__, 'getAuthSessionErrorUrl')) . $query_string);
+        SyL_Response::redirect(call_user_func(array(__CLASS__, 'getAuthSessionErrorUrl')));
     }
-
 }
 
 ?>
