@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.9 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.10 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.9 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.10 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -60,16 +60,6 @@ class SyL_Context
      * @var string
      */
     var $parameters = array();
-    /**
-     * ޥӥ塼ѥ᡼
-     * 
-     * @access private
-     * @var array
-     */
-    var $customized_view = array(
-      'class' => '',
-      'file'  => ''
-    );
     /**
      * ӥ塼
      * 
@@ -289,41 +279,6 @@ class SyL_Context
         return $this->layout_name;
     }
 
-    /**
-     * ޥӥ塼饹򥻥å
-     *
-     * @access public
-     * @param string ޥӥ塼饹̾
-     * @param string ޥӥ塼ե̾
-     */
-    function setCustomizedView($classname, $filename)
-    {
-        $this->customized_view['class'] = $classname;
-        $this->customized_view['file']  = $filename;
-    }
-
-    /**
-     * ޥӥ塼饹
-     *
-     * @access public
-     * @return string ޥӥ塼饹
-     */
-    function getCustomizedViewClass()
-    {
-        return $this->customized_view['class'];
-    }
-
-    /**
-     * ޥӥ塼ե
-     *
-     * @access public
-     * @return string ޥӥ塼ե
-     */
-    function getCustomizedViewFile()
-    {
-        return $this->customized_view['file'];
-    }
-
     /**
      * ݡͥȥ֥Ȥ򥻥å
      * 
