@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.27 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.28 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.27 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.28 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -184,6 +184,8 @@ class SyL_Controller
         define('SYL_APP_DIR', SYL_PROJECT_DIR . '/apps/' . $config['app_name']);
         // ץꥱեǥ쥯ȥ
         define('SYL_APP_CONFIG_DIR', SYL_APP_DIR . '/config');
+        // ץꥱ饤֥ǥ쥯ȥ
+        define('SYL_APP_LIB_DIR', SYL_APP_DIR . '/lib');
 
         // å
         define('SYL_CACHE', (isset($config['cache']) && $config['cache']) ? $config['cache'] : false);
