@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.13 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.14 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.13 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.14 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -138,22 +138,23 @@ class SyL_Response
     }
 
     /**
-     * 404 Not Found 쥯Ȥ
+     * 404 Not Found ̤˥եɤ
      *
      * @access public
-     * @param string URL
      */
-    function redirect404()
+    function forward404()
     {
+        // Хåե󥰥ꥢ
+        if (!headers_sent() && (ob_get_level() > 0)) {
+            ob_clean();
+        }
+
         SyL_Response::setStatusHeader('404');
+        SyL_Loggers::info("[Response] 404 Not Found");
         if (SYL_ENV_TYPE == 'web') {
-            $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
-            SyL_Loggers::info("[Response] 404 Not Found - {$request_uri}");
-            if (SYL_ERROR_URL_404) {
-                SyL_Response::redirect(SYL_ERROR_URL_404);
-            } else {
-                echo "<h2>HTTP/1.0 404 Not Found</h2>";
-            }
+            include_once SYL_ERROR_FORWARD_FILE_404;
+        } else {
+            echo "File Not Found";
         }
         exit;
     }
