@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.2 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.3 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,10 +39,10 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.2 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.3 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_UtilUseragent
+class SyL_UtilUserAgent
 {
     /**
      * [U[G[WFg
@@ -136,7 +136,6 @@ class SyL_UtilUseragent
       'Mozilla'           => 'Mozilla',
       'W3C'               => 'W3C Validator',
       'Wget'              => 'Wget'
-
     );
 
     /**
@@ -158,13 +157,65 @@ class SyL_UtilUseragent
       'PDXGW'      => 'WILLCOM'
     );
 
+    /**
+     * ROBOTzi}X^j
+     *
+     * @access private
+     * @var array
+     */
+    var $robots = array(
+      'Googlebot-Image'  => 'Googlebot-Image',
+      'Googlebot-Mobile' => 'Googlebot-Mobile',
+      'Googlebot'        => 'Googlebot',
+      'Yahoo-MMCrawler'  => 'Yahoo-MMCrawler',
+      'Yahoo! Slurp'     => 'Yahoo! Slurp',
+      'Y!J-'             => 'Y!J',
+      'msnbot-media'     => 'msnbot-media',
+      'msnbot-NewsBlogs' => 'msnbot-NewsBlogs',
+      'msnbot'           => 'msnbot',
+      'Yeti'             => 'YetiBot',
+      'Baiduspider'      => 'Baiduspider',
+      'boitho.com-dc'    => 'boitho.com-dc',
+      'blogoonbot'       => 'blogoonbot',
+      'Comaneci_bot'     => 'Comaneci_bot',
+      'e-SocietyRobot'   => 'e-SocietyRobot',
+      'Gaisbot'          => 'Gaisbot',
+      'GurujiBot'        => 'GurujiBot',
+      'ICC-Crawler'      => 'ICC-Crawler',
+      'ichiro'           => 'ichiro',
+      'InfoSeek Sidewinder' => 'InfoSeek Sidewinder',
+      'IDBot'         => 'IDBot',
+      'IRLbot'        => 'IRLbot',
+      'Jyxobot'       => 'Jyxobot',
+      'Keywalkerbot'  => 'Keywalkerbot',
+      'Modiphibot'    => 'Modiphibot',
+      'MaplogCrawler' => 'MaplogCrawler',
+      'MaSagool'      => 'MaSagool',
+      'MJ12bot'       => 'MJ12bot',
+      'multicrawler'  => 'multicrawler',
+      'NaverBot'      => 'NaverBot',
+      'Nutch'         => 'Nutch',
+      'mootercrawler' => 'mootercrawler',
+      'psbot'         => 'psbot',
+      'RedBot'        => 'RedBot',
+      'Robo Crawler'  => 'Robo Crawler',
+      'Snapbot'       => 'Snapbot',
+      'Steeler'       => 'Steeler',
+      'SurveyBot'     => 'SurveyBot',
+      'YodaoBot'      => 'YodaoBot',
+      'TurnitinBot'   => 'TurnitinBot',
+      'Twiceler-'     => 'Twiceler',
+      'Vajradhara'    => 'Vajradhara',
+      'WebGenBot'     => 'WebGenBot'
+    );
+
     /**
      * RXgN^
      *
      * @access public
      * @param string [U[G[WFg
      */
-    function SyL_UtilUseragent($user_agent='')
+    function SyL_UtilUserAgent($user_agent='')
     {
         if ($user_agent) {
             $this->user_agent = $user_agent;
@@ -184,6 +235,17 @@ class SyL_UtilUseragent
         return ($this->getCarrier() !== null);
     }
 
+    /**
+     * {bgs
+     *
+     * @access public
+     * @return bool true: {bgAfalse: {bgȊO
+     */
+    function isRobot()
+    {
+        return ($this->getRobot() !== null);
+    }
+
     /**
      * vbgtH[iOSj擾
      *
@@ -285,6 +347,23 @@ class SyL_UtilUseragent
         }
         return null;
     }
+
+    /**
+     * {bg擾
+     *
+     * @access public
+     * @return string {bg
+     */
+    function getRobot()
+    {
+        foreach ($this->robots as $key => $value) {
+            $reg = '/' . preg_quote($key, '/') . '[ |\/]?([0-9\.\/]+)?.*/i';
+            if (preg_match($reg, $this->user_agent, $matches)) {
+                return isset($matches[1]) ? $value . ' ' . $matches[1] : $value;
+            }
+        }
+        return null;
+    }
 }
 
 ?>
